@@ -10,14 +10,19 @@
 Usage:
    example2_mpl.py [fits file]
 
-You need Qt4 with python bindings (or pyside) installed to run this example.
+You need Qt5 or Qt6 with pyqt bindings (or pyside) installed to run this
+example.
 """
 import sys
 
+from ginga import toolkit
+toolkit.use('qt')
+
 from matplotlib.figure import Figure
 
 from ginga.qtw.QtHelp import QtGui, QtCore
-from ginga.mplw.ImageViewCanvasMpl import ImageViewCanvas
+from ginga.qtw import QtHelp
+from ginga.mplw.ImageViewMpl import CanvasView
 from ginga.mplw.FigureCanvasQt import FigureCanvas
 from ginga.misc import log
 from ginga import colors
@@ -36,15 +41,15 @@ class FitsViewer(QtGui.QMainWindow):
         fig = Figure()
         w = FigureCanvas(fig)
 
-        fi = ImageViewCanvas(logger=logger)
+        fi = CanvasView(logger=logger)
         fi.enable_autocuts('on')
         fi.set_autocut_params('zscale')
         fi.enable_autozoom('on')
-        fi.enable_draw(False)
         fi.set_callback('drag-drop', self.drop_file_cb)
         fi.set_callback('cursor-changed', self.cursor_cb)
         fi.set_bg(0.2, 0.2, 0.2)
         fi.ui_set_active(True)
+        fi.show_mode_indicator(True, corner='ur')
         self.fitsimage = fi
         fi.set_figure(fig)
 
@@ -79,7 +84,7 @@ class FitsViewer(QtGui.QMainWindow):
         hbox.setContentsMargins(QtCore.QMargins(4, 2, 4, 2))
 
         wdrawtype = QtGui.QComboBox()
-        self.drawtypes = fi.get_drawtypes()
+        self.drawtypes = canvas.get_drawtypes()
         for name in self.drawtypes:
             wdrawtype.addItem(name)
         index = self.drawtypes.index('rectangle')
@@ -257,6 +262,9 @@ class FitsViewer(QtGui.QMainWindow):
 
 def main(options, args):
 
+    if QtHelp.have_pyqt6 or QtHelp.have_pyside6:
+        QtGui.QApplication.setHighDpiScaleFactorRoundingPolicy(
+            QtCore.Qt.HighDpiScaleFactorRoundingPolicy.Floor)
     app = QtGui.QApplication(args)
 
     logger = log.get_logger(name="example2", options=options)
