@@ -582,11 +582,17 @@ class QtEventMixin(object):
     def focus_event(self, widget, event, hasFocus):
         return self.make_callback('focus', hasFocus)
 
+    def _get_pos(self, event):
+        if hasattr(event, 'position'):
+            pos = event.position()
+            return pos.x(), pos.y()
+        else:
+            pos = event.pos()
+            return pos.x(), pos.y()
+
     def enter_notify_event(self, widget, event):
-        if hasattr(event, 'x'):
-            # only Qt5 apparently?
-            self.last_win_x, self.last_win_y = event.x(), event.y()
-            self.check_cursor_location()
+        self.last_win_x, self.last_win_y = self._get_pos(event)
+        self.check_cursor_location()
 
         enter_focus = self.t_.get('enter_focus', False)
         if enter_focus:
@@ -613,13 +619,13 @@ class QtEventMixin(object):
 
     def button_press_event(self, widget, event):
         buttons = event.buttons()
-        x, y = event.x(), event.y()
+        x, y = self._get_pos(event)
         self.last_win_x, self.last_win_y = x, y
 
         button = 0
         if buttons & QtCore.Qt.LeftButton:
             button |= 0x1
-        if buttons & QtCore.Qt.MidButton:
+        if buttons & QtCore.Qt.MiddleButton:
             button |= 0x2
         if buttons & QtCore.Qt.RightButton:
             button |= 0x4
@@ -637,13 +643,13 @@ class QtEventMixin(object):
     def button_release_event(self, widget, event):
         # note: for mouseRelease this needs to be button(), not buttons()!
         buttons = event.button()
-        x, y = event.x(), event.y()
+        x, y = self._get_pos(event)
         self.last_win_x, self.last_win_y = x, y
 
         button = 0
         if buttons & QtCore.Qt.LeftButton:
             button |= 0x1
-        if buttons & QtCore.Qt.MidButton:
+        if buttons & QtCore.Qt.MiddleButton:
             button |= 0x2
         if buttons & QtCore.Qt.RightButton:
             button |= 0x4
@@ -669,13 +675,13 @@ class QtEventMixin(object):
             return True
 
         buttons = event.buttons()
-        x, y = event.x(), event.y()
+        x, y = self._get_pos(event)
         self.last_win_x, self.last_win_y = x, y
 
         button = 0
         if buttons & QtCore.Qt.LeftButton:
             button |= 0x1
-        if buttons & QtCore.Qt.MidButton:
+        if buttons & QtCore.Qt.MiddleButton:
             button |= 0x2
         if buttons & QtCore.Qt.RightButton:
             button |= 0x4
@@ -686,7 +692,7 @@ class QtEventMixin(object):
                                             data_x, data_y)
 
     def scroll_event(self, widget, event):
-        x, y = event.x(), event.y()
+        x, y = self._get_pos(event)
         # accept event here so it doesn't get propagated to parent
         event.accept()
         self.last_win_x, self.last_win_y = x, y
