@@ -9,7 +9,7 @@ import pathlib
 from functools import reduce
 
 from ginga.qtw.QtHelp import (QtGui, QtCore, QTextCursor, QIcon, QPixmap,
-                              QImage, QCursor, QFont, have_pyqt4)
+                              QImage, QCursor, QFont)
 from ginga.qtw import QtHelp
 
 from ginga.misc import Callback, Bunch, Settings, LineHistory
@@ -105,9 +105,20 @@ class WidgetBase(Callback.Callbacks):
         font = QtHelp.get_font(font_family, point_size)
         return font
 
-    def cfg_expand(self, horizontal=0, vertical=0):
-        h_policy = QtGui.QSizePolicy.Policy(horizontal)
-        v_policy = QtGui.QSizePolicy.Policy(vertical)
+    def cfg_expand(self, horizontal='fixed', vertical='fixed'):
+        """WARNING: this call has specific effects dependent on the back
+        end. It is not recommended to use it unless you cannot achieve the
+        proper layout without it.
+        """
+        policy_dict = dict(fixed=QtGui.QSizePolicy.Fixed,
+                           minimum=QtGui.QSizePolicy.Minimum,
+                           maximum=QtGui.QSizePolicy.Maximum,
+                           preferred=QtGui.QSizePolicy.Preferred,
+                           expanding=QtGui.QSizePolicy.Expanding,
+                           minimumexpanding=QtGui.QSizePolicy.MinimumExpanding,
+                           ignored=QtGui.QSizePolicy.Ignored)
+        h_policy = QtGui.QSizePolicy.Policy(policy_dict[horizontal])
+        v_policy = QtGui.QSizePolicy.Policy(policy_dict[vertical])
         self.widget.setSizePolicy(QtGui.QSizePolicy(h_policy, v_policy))
 
 
@@ -227,7 +238,7 @@ class GrowingTextEdit(QtGui.QTextEdit):
         # add some margin to prevent auto scrollbars
         docHeight += 20
         if self.heightMin <= docHeight <= self.heightMax:
-            self.setMaximumHeight(docHeight)
+            self.setMaximumHeight(int(docHeight))
 
 
 class TextArea(WidgetBase):
@@ -309,7 +320,7 @@ class Label(WidgetBase):
             menu_w = menu.get_widget()
 
             def on_context_menu(point):
-                menu_w.exec_(lbl.mapToGlobal(point))
+                menu_w.exec(lbl.mapToGlobal(point))
 
             lbl.customContextMenuRequested.connect(on_context_menu)
 
@@ -690,7 +701,7 @@ class Image(WidgetBase):
             menu_w = menu.get_widget()
 
             def on_context_menu(point):
-                menu_w.exec_(lbl.mapToGlobal(point))
+                menu_w.exec(lbl.mapToGlobal(point))
 
             lbl.customContextMenuRequested.connect(on_context_menu)
 
@@ -729,8 +740,12 @@ class StatusBar(WidgetBase):
         super(StatusBar, self).__init__()
 
         sbar = QtGui.QStatusBar()
+        sbar.setSizeGripEnabled(True)
         self.widget = sbar
 
+    def clear_message(self):
+        self.widget.showMessage('', 0)
+
     def set_message(self, msg_str, duration=10.0):
         # remove message in about `duration` seconds
         self.widget.showMessage(msg_str, int(duration * 1000))
@@ -994,6 +1009,9 @@ class TreeView(WidgetBase):
         for i in range(len(self.columns)):
             self.widget.resizeColumnToContents(i)
 
+    def get_column_widths(self):
+        return [self.widget.columnWidth(i) for i in range(len(self.columns))]
+
     def _start_drag(self, event):
         res_dict = self.get_selected()
         drag_pkg = DragPackage(self.widget)
@@ -1109,13 +1127,13 @@ class Box(ContainerBase):
         self.layout.setContentsMargins(0, 0, 0, 0)
         self.widget.setLayout(self.layout)
 
-    def insert_widget(self, idx, child, stretch=0.0):
+    def insert_widget(self, idx, child, stretch=0):
         self.add_ref(child)
         child_w = child.get_widget()
         self.layout.insertWidget(idx, child_w, stretch=stretch)
         self.make_callback('widget-added', child)
 
-    def add_widget(self, child, stretch=0.0):
+    def add_widget(self, child, stretch=0):
         self.add_ref(child)
         child_w = child.get_widget()
         self.layout.addWidget(child_w, stretch=stretch)
@@ -1762,10 +1780,10 @@ class Menu(ContainerBase):
             w = widget.get_widget()
             if w.isEnabled():
                 # self.widget.popup(w.mapToGlobal(QtCore.QPoint(0, 0)))
-                self.widget.exec_(w.mapToGlobal(QtCore.QPoint(0, 0)))
+                self.widget.exec(w.mapToGlobal(QtCore.QPoint(0, 0)))
         else:
             if self.widget.isEnabled():
-                self.widget.exec_(QCursor.pos())
+                self.widget.exec(QCursor.pos())
 
     def get_menu(self, name):
         return self.menus[name]
@@ -1989,7 +2007,6 @@ class Application(Callback.Callbacks):
         self.window_list = []
         self.window_dict = {}
         self.wincnt = 0
-
         if self.settings.get('use_opengl', False):
             # ensure we are using correct version of opengl
             # NOTE: On MacOSX w/Qt it is necessary to set the default OpenGL
@@ -1997,23 +2014,28 @@ class Application(Callback.Callbacks):
             # shares the OpenGL context
             QtHelp.set_default_opengl_context()
 
-        if have_pyqt4:
-            QtGui.QApplication.setGraphicsSystem('raster')
+        # NOTE: the default value of "PassThrough" allows odd scaling
+        # factors that can make text and icon rendering look terrible
+        # on some platforms
+        if QtHelp.have_pyqt6 or QtHelp.have_pyside6:
+            QtGui.QApplication.setHighDpiScaleFactorRoundingPolicy(
+                QtCore.Qt.HighDpiScaleFactorRoundingPolicy.Floor)
+
         app = QtGui.QApplication([])
         # app.lastWindowClosed.connect(lambda *args: self._quit())
         self._qtapp = app
         _app = self
 
         # Get screen size
-        desktop = self._qtapp.desktop()
-        rect = desktop.availableGeometry()
+        screen = app.primaryScreen()
+        rect = screen.availableGeometry()
         size = rect.size()
         self.screen_wd = size.width()
         self.screen_ht = size.height()
 
         # Get screen resolution
-        xdpi = desktop.physicalDpiX()
-        ydpi = desktop.physicalDpiY()
+        xdpi = screen.physicalDotsPerInchX()
+        ydpi = screen.physicalDotsPerInchY()
         self.screen_res = max(xdpi, ydpi)
 
         for name in ('shutdown', ):
@@ -2056,7 +2078,7 @@ class Application(Callback.Callbacks):
         return QtHelp.Timer()
 
     def mainloop(self):
-        self._qtapp.exec_()
+        self._qtapp.exec()
 
     def quit(self):
         self._qtapp.quit()
@@ -2148,10 +2170,7 @@ class DragPackage(object):
         self._data.setText(text)
 
     def start_drag(self):
-        if QtHelp.have_pyqt5:
-            self._drag.exec_(QtCore.Qt.MoveAction)
-        else:
-            self._drag.start(QtCore.Qt.MoveAction)
+        self._drag.exec(QtCore.Qt.MoveAction)
 
 
 # MODULE FUNCTIONS
@@ -2206,11 +2225,11 @@ def make_widget(title, wtype):
         w = VBox()
     elif wtype == 'hbox':
         w = HBox()
-    elif wtype == 'hscale':
+    elif wtype in ('hslider', 'hscale'):
         w = Slider(orientation='horizontal')
-    elif wtype == 'vscale':
+    elif wtype in ('vslider', 'vscale'):
         w = Slider(orientation='vertical')
-    elif wtype == 'checkbutton':
+    elif wtype in ('checkbox', 'checkbutton'):
         w = CheckBox(title)
     elif wtype == 'radiobutton':
         w = RadioButton(title)
